==> sword-1.5.0.tar.gz: sword-1.5.0/apps/X11/VCL/TTreeView.h <==
#ifndef TTREEVIEW_H
#define TTREEVIEW_H

#include <TCustomTreeView.h>

class TTreeView : public TCustomTreeView {
public:
//	property Items;
	property <TTreeView, TTreeNodes *> Items;
//	property StateImages;
	property <TTreeView, TCustomImageList *> StateImages;
//	property Images;
	property <TTreeView, TCustomImageList *> Images;
//published:
/*
    property Align;
    property Anchors;
    property AutoExpand;
    property BiDiMode;
    property BorderStyle;
    property BorderWidth;
    property ChangeDelay;
    property Color;
    property Ctl3D;
    property Constraints;
    property DragKind;
    property DragCursor;
    property DragMode;
    property Enabled;
    property Font;
    property HideSelection;
    property HotTrack;
    property Indent;
    property ParentBiDiMode;
    property ParentColor default False;
    property ParentCtl3D;
    property ParentFont;
    property ParentShowHint;
    property PopupMenu;
    property ReadOnly;
    property RightClickSelect;
    property RowSelect;
    property ShowButtons;
    property ShowHint;
    property ShowLines;
    property ShowRoot;
    property SortType;
    property TabOrder;
    property TabStop default True;
    property ToolTips;
    property Visible;
    property OnChange;
    property OnChanging;
    property OnClick;
    property OnCollapsing;
    property OnCollapsed;
    property OnCompare;
    property OnCustomDraw;
    property OnCustomDrawItem;
    property OnDblClick;
    property OnDeletion;
    property OnDragDrop;
    property OnDragOver;
    property OnEdited;
    property OnEditing;
    property OnEndDock;
    property OnEndDrag;
    property OnEnter;
    property OnExit;
    property OnExpanding;
    property OnExpanded;
    property OnGetImageIndex;
    property OnGetSelectedIndex;
    property OnKeyDown;
    property OnKeyPress;
    property OnKeyUp;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;
    property OnStartDock;
    property OnStartDrag;
*/
public:
	TTreeView(GtkWidget *parent) :
		TCustomTreeView(parent),
		Items(this, &getItems, &SetTreeNodes),
		StateImages(this, &getStateImages, &SetStateImages),
		Images(this, &getImages, &SetImages)
		{}
};

#endif

==> sword_1.5.3.orig.tar.gz: sword-1.5.3.orig/apps/X11/VCL/TTreeView.h <==
#ifndef TTREEVIEW_H
#define TTREEVIEW_H

#include <TCustomTreeView.h>

class TTreeView : public TCustomTreeView {
public:
//	property Items;
	property <TTreeView, TTreeNodes *> Items;
//	property StateImages;
	property <TTreeView, TCustomImageList *> StateImages;
//	property Images;
	property <TTreeView, TCustomImageList *> Images;
//published:
/*
    property Align;
    property Anchors;
    property AutoExpand;
    property BiDiMode;
    property BorderStyle;
    property BorderWidth;
    property ChangeDelay;
    property Color;
    property Ctl3D;
    property Constraints;
    property DragKind;
    property DragCursor;
    property DragMode;
    property Enabled;
    property Font;
    property HideSelection;
    property HotTrack;
    property Indent;
    property ParentBiDiMode;
    property ParentColor default False;
    property ParentCtl3D;
    property ParentFont;
    property ParentShowHint;
    property PopupMenu;
    property ReadOnly;
    property RightClickSelect;
    property RowSelect;
    property ShowButtons;
    property ShowHint;
    property ShowLines;
    property ShowRoot;
    property SortType;
    property TabOrder;
    property TabStop default True;
    property ToolTips;
    property Visible;
    property OnChange;
    property OnChanging;
    property OnClick;
    property OnCollapsing;
    property OnCollapsed;
    property OnCompare;
    property OnCustomDraw;
    property OnCustomDrawItem;
    property OnDblClick;
    property OnDeletion;
    property OnDragDrop;
    property OnDragOver;
    property OnEdited;
    property OnEditing;
    property OnEndDock;
    property OnEndDrag;
    property OnEnter;
    property OnExit;
    property OnExpanding;
    property OnExpanded;
    property OnGetImageIndex;
    property OnGetSelectedIndex;
    property OnKeyDown;
    property OnKeyPress;
    property OnKeyUp;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;
    property OnStartDock;
    property OnStartDrag;
*/
public:
	TTreeView(GtkWidget *parent) :
		TCustomTreeView(parent),
		Items(this, &TCustomTreeView::getItems, &TCustomTreeView::SetTreeNodes),
		StateImages(this, &TCustomTreeView::getStateImages, &TCustomTreeView::SetStateImages),
		Images(this, &TCustomTreeView::getImages, &TCustomTreeView::SetImages)
		{}
};

#endif
